﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;

using Arction.WinForms.Charting;
using Arction.WinForms.Charting.EventMarkers;
using Arction.WinForms.Charting.SeriesXY;
using Arction.WinForms.Charting.Views.ViewXY;

namespace AL_CursorCrosshair
{
    public partial class FormMain : Form
    {
        #region Membervariables

        private LightningChartUltimate _lcu;
        private ViewXY _view;
        private CrosshairCursor _cursor;
        private Random _random = new Random();

        #endregion

        #region Constructor

        public FormMain()
        {
            InitializeComponent();
            CreateChart();
        }

        #endregion
        #region CreateChart

        private void CreateChart()
        {
            _lcu = new LightningChartUltimate();
            _lcu.Dock = DockStyle.Fill;
            _lcu.ColorTheme = ColorTheme.LightGray;
            _lcu.Title.Visible = false;

            _lcu.ActiveView = ActiveView.ViewXY;
            _view = _lcu.ViewXY;
            _view.LegendBox.Visible = false;

            var xaxis = _view.XAxes[0];
            xaxis.SetRange(-10, 50);
            xaxis.ValueType = AxisValueType.Number;
            _view.YAxes[0].SetRange(-10, 50);

            #region Sample Graph

            var series = new IntensityGridSeries(_view, _view.XAxes[0], _view.YAxes[0])
            {
                PixelRendering = true,
                Optimization = IntensitySeriesOptimization.DynamicData,
                DisableDragToAnotherAxis = true,
                FullInterpolation = false,
                MouseInteraction = false,
                MouseHighlight = MouseOverHighlight.None,
            };

            int rows = 10;
            int cols = 10;
            var data = new double[cols][];

            for (int x=0; x<cols; x++)
            {
                var col = new double[rows];
                data[x] = col;
                for (int y=0;y<rows;y++)
                {
                    data[x][y] = _random.NextDouble() * 30;
                }
            }

            series.SetSize(cols, rows);
            series.SetRangesXY(0, 40, 0, 40);
            series.SetValuesData(data, IntensityGridValuesDataOrder.ColumnsRows);


            _view.IntensityGridSeries.Add(series);

            #endregion

            _cursor = new CrosshairCursor(0, _view, _view.XAxes[0], _view.YAxes[0]);
            _cursor.CursorMoved += CursorOnCursorMoved;
            _cursor.SetPositions(20, 20);

            Controls.Add(_lcu);
            _lcu.BringToFront();
        }

        #endregion

        private void CursorOnCursorMoved(object sender, CursorEventArgs cursorEventArgs)
        {
            // ...
        }
    }
}
